# Documentation: Wireless Decentralized Network Prototype

## Table of Contents
1. [Introduction](#introduction)
2. [Requirements](#requirements)
3. [Approaches](#approaches)
   - [LoRa/WAN Approach](#lora-wan-approach)
   - [BLE Approach](#ble-approach)
   - [WLAN Approach](#wlan-approach)
4. [Devices Used and Tested](#devices-used-and-tested)
5. [Development Environments](#development-environments)
6. [Challenges and Issues](#challenges-and-issues)
   - [BLE Issues](#ble-issues)
   - [LoRa/WAN Issues](#lora-wan-issues)
   - [WLAN Issues](#wlan-issues)
   - [ESP-MESH](#esp-mesh)
7. [Conclusion](#conclusion)

---

## Introduction

The wireless decentralized network prototype aims to explore the feasibility of creating a low-power communication network for agricultural purposes. This network is designed to facilitate communication between devices over long distances without the need for traditional centralized infrastructure. Several communication protocols and hardware devices were tested, and their performance and feasibility were analyzed to determine the most suitable approach.

## Requirements

- Low-power communication between devices.
- Decentralized structure (no need for a central hub or server).
- Support for long-range communication across large fields (e.g., agricultural applications).
- Flexible communication protocol to support a variety of devices.

## Approaches

The following communication protocols were explored in our prototype development:

### LoRa/WAN Approach
LoRa (Long Range) is a wireless technology that allows for long-distance communication with low power consumption. LoRaWAN adds a network layer to LoRa, enabling devices to connect over large distances with minimal power usage. This protocol is often favored for IoT projects requiring long-range communication.

### BLE Approach
Bluetooth Low Energy (BLE) is a short-range wireless communication protocol designed for low-power devices. It is suitable for small data packets over shorter distances but faces limitations in range compared to other technologies like LoRa.

### WLAN Approach
WLAN (Wireless Local Area Network) communication via ESP-NOW is a low-power communication technology that allows devices to communicate directly without a router. It provides low-latency data transmission but is limited in range.

## Devices Used and Tested

| Device               | Communication Type  | Notes                                  |
|----------------------|---------------------|----------------------------------------|
| Raspberry Pi Pico     | BLE                 | Stack issues during compilation        |
| Rak Wireless          | LoRa/WAN            | Limited due to single module availability |
| ESP8266 (ESP-NOW)       | WLAN                | Successful testing with low power usage |

## Development Environments

- **Arduino IDE**: Used to develop and test with **Rak Wireless** and **ESP8266** for both LoRa/WAN and WLAN.
- **VSCode**: Used for developing on **Raspberry Pi Pico** with BLE, though the BLE stack compilation issues halted progress.

## Challenges and Issues

### BLE Issues

- The Bluetooth stack for the **Raspberry Pi Pico** did not compile, resulting in the inability to transmit or receive data.
- No usable data could be exchanged via the BLE approach, which halted further development and testing with BLE for this project.

### LoRa/WAN Issues

- We only had **one LoRa/WAN module**, meaning we could only transmit or receive data, but not establish a complete network.
- Due to the absence of multiple modules, we couldn’t properly test the decentralized network capabilities.
  
### WLAN Issues

- The **ESP-NOW** protocol using **ESP8266** was successful in terms of data transmission and reception with low power consumption.
- However, the **range limitations** are a concern. ESP-NOW can reach about **480 meters in good conditions**, which is significantly less than the **16 km** range achievable with LoRa under ideal conditions.
- For small-scale or prototype testing, WLAN (ESP-NOW) is sufficient, but in large agricultural fields, the shorter range may become a critical issue.

### ESP-MESH
- The continuation of the **ESP-NOW** protocol is done in the **ESP-MESH** protocol however that is only usable the ESP32 variations which we dont have enough of to build a decentralized network, we also had problems talking to the ESP32 which in turn ment that we could not work with it.

## Conclusion

In this project, we explored three different approaches—LoRa/WAN, BLE, and WLAN (ESP-NOW)—for building a decentralized, wireless communication network. Each technology has its own advantages and limitations:

- **LoRa/WAN** offers the best long-range communication but was hindered by the availability of only one module, preventing a full test.
- **BLE** is not viable due to the compilation issues and range limitations.
- **WLAN (ESP-NOW)**, though limited in range compared to LoRa, showed promise for short-distance, low-power communication in prototype testing.
---
- **Hardware** we hat a lot of problems finding the right hardware to do the job because either we experienced unusual errors that we could not solve or the device was incapable of the protocol we are trying to develop with 

For future developments, expanding the availability of **LoRa/WAN modules** would be ideal, as it would allow for thorough testing and deployment of a long-range communication network suitable for large-scale agricultural fields. For small areas, **ESP-NOW** may suffice, but further testing is required to determine if it meets all the field requirements.
